@@ -15,10 +15,8 @@ from typing import Any, Dict, List, Optional
 from mitosheet._version import __version__
 from mitosheet.telemetry.telemetry_utils import log
 from mitosheet.types import StepsManagerType
-
-
-# Where all global .mito files are stored
-MITO_FOLDER = os.path.expanduser("~/.mito")
+from mitosheet.utils import NpEncoder
+from mitosheet.save_paths import MITO_FOLDER
 
 # The current version of the saved Mito analysis
 # where we save all the analyses for this version
@@ -122,14 +120,14 @@ def rename_saved_analysis(old_analysis_name, new_analysis_name):
         raise Exception(f'Invalid rename, with old and new analysis are {old_analysis_name} and {new_analysis_name}')
 
 
-def write_saved_analysis(analysis_path: str, steps_data: List[Dict[str, Any]], version: str=__version__) -> None:
+def write_saved_analysis(analysis_path: str, steps_data: List[Dict[str, Any]], public_interface_version: int, version: str=__version__) -> None:
     with open(analysis_path, 'w+') as f:
         saved_analysis = {
             'version': version,
-            'steps_data': steps_data
+            'steps_data': steps_data,
+            'public_interface_version': public_interface_version
         }
-
-        f.write(json.dumps(saved_analysis))
+        f.write(json.dumps(saved_analysis, cls=NpEncoder))
 
 
 def make_steps_json_obj(
@@ -183,7 +181,7 @@ def make_steps_json_obj(
 
     return steps_json_obj
 
-def write_analysis(steps_manager: StepsManagerType, analysis_name: str=None) -> None:
+def write_analysis(steps_manager: StepsManagerType, analysis_name: Optional[str]=None) -> None:
     """
     Writes the analysis saved in steps_manager to
     ~/.mito/{analysis_name}. If analysis_name is none, gets the temporary
@@ -204,15 +202,7 @@ def write_analysis(steps_manager: StepsManagerType, analysis_name: str=None) ->
         analysis_name = steps_manager.analysis_name
 
     analysis_path = f'{SAVED_ANALYSIS_FOLDER}/{analysis_name}.json'
-    steps = make_steps_json_obj(steps_manager.steps)
+    steps = make_steps_json_obj(steps_manager.steps_including_skipped)
 
     # Actually write the file
-    write_saved_analysis(analysis_path, steps)
-
-
-def register_analysis(analysis_name):
-    """
-    A helper function that is used in the frontend
-    to save which analysis is being run (so it can be replayed)
-    """
-    log('ran_generated_code', {'analysis_name': analysis_name}) 
\ No newline at end of file
+    write_saved_analysis(analysis_path, steps, steps_manager.public_interface_version)
\ No newline at end of file
