@@ -5,18 +5,15 @@
 # Distributed under the terms of the GPL License.
 from copy import deepcopy
 from time import perf_counter
-from typing import Any, Dict, List, Optional, Set, Union
+from typing import Any, Dict, List, Optional, Set, Tuple, Union
+from mitosheet.code_chunks.code_chunk import CodeChunk
+from mitosheet.code_chunks.step_performers.drop_duplicates_code_chunk import DropDuplicatesCodeChunk
 
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
-from mitosheet.transpiler.transpile_utils import (
-    column_header_list_to_transpiled_code, column_header_to_transpiled_code)
+from mitosheet.step_performers.utils import get_param
 from mitosheet.types import ColumnID
 
-# CONSTANTS USED IN THE SORT STEP ITSELF
-ASCENDING = 'ascending'
-DESCENDING = 'descending'
-
 class DropDuplicatesStepPerformer(StepPerformer):
     """
     Allows you to drop duplicates from a dataframe
@@ -29,24 +26,13 @@ class DropDuplicatesStepPerformer(StepPerformer):
     @classmethod
     def step_type(cls) -> str:
         return 'drop_duplicates'
-    
-    @classmethod
-    def step_display_name(cls) -> str:
-        return 'Dropped Duplicates'
 
     @classmethod
-    def saturate(cls, prev_state: State, params: Dict[str, Any]) -> Dict[str, Any]:
-        return params
+    def execute(cls, prev_state: State, params: Dict[str, Any]) -> Tuple[State, Optional[Dict[str, Any]]]:
+        sheet_index = get_param(params, 'sheet_index')
+        column_ids = get_param(params, 'column_ids')
+        keep = get_param(params, 'keep')
 
-    @classmethod
-    def execute( # type: ignore
-        cls,
-        prev_state: State,
-        sheet_index: int,
-        column_ids: List[ColumnID],
-        keep: Union[str, bool],
-        **params
-    ):
         column_headers = [
             prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
             for column_id in column_ids
@@ -55,7 +41,7 @@ class DropDuplicatesStepPerformer(StepPerformer):
         # If the subset is none, then we don't actually do the drop, as there are no
         # duplicates between 0 columns
         if len(column_headers) == 0:
-            return None
+            return prev_state, {}
 
         # We make a new state to modify it
         post_state = prev_state.copy(deep_sheet_indexes=[sheet_index])
@@ -67,67 +53,37 @@ class DropDuplicatesStepPerformer(StepPerformer):
         )
         pandas_processing_time = perf_counter() - pandas_start_time
 
+
         post_state.dfs[sheet_index] = final_df
 
+        # We calculate the number of rows dropped, so we can return this to the frontend
+        num_rows_dropped = len(prev_state.dfs[sheet_index].index) - len(post_state.dfs[sheet_index].index)
+
         return post_state, {
-            'pandas_processing_time': pandas_processing_time
+            'pandas_processing_time': pandas_processing_time,
+            'result': {
+                'num_rows_dropped': num_rows_dropped
+            }
         }
 
     @classmethod
-    def transpile( # type: ignore
+    def transpile(
         cls,
         prev_state: State,
         post_state: State,
+        params: Dict[str, Any],
         execution_data: Optional[Dict[str, Any]],
-        sheet_index: int,
-        column_ids: List[ColumnID],
-        keep: Union[str, bool],
-    ) -> List[str]:
-
-        column_headers = [
-            prev_state.column_ids.get_column_header_by_id(sheet_index, column_id)
-            for column_id in column_ids
-        ]
-
-        # If the subset is none, then we don't actually do the drop, as there are no
-        # duplicates between 0 columns
-        if len(column_headers) == 0:
-            return []
-        
-        # We leave subset and keep empty if they are not used
-        param_string = ''
-        if len(column_headers) != len(post_state.dfs[sheet_index].keys()):
-            param_string += 'subset=' + column_header_list_to_transpiled_code(column_headers) + ', '
-        
-        param_string += 'keep=' + column_header_to_transpiled_code(keep) # not a column header, but we can use the same utility
-
-        df_name = post_state.df_names[sheet_index]
-
+    ) -> List[CodeChunk]:
         return [
-            f'{df_name} = {df_name}.drop_duplicates({param_string})'
+            DropDuplicatesCodeChunk(
+                prev_state, 
+                post_state, 
+                get_param(params, 'sheet_index'),
+                get_param(params, 'column_ids'),
+                get_param(params, 'keep')
+            )   
         ]
 
-
     @classmethod
-    def describe( # type: ignore
-        cls,
-        sheet_index: int,
-        column_ids: List[ColumnID],
-        keep: str,
-        df_names=None,
-        **params
-    ) -> str:
-        if df_names is not None:
-            df_name = df_names[sheet_index]
-            return f'Drop duplicates in {df_name}'
-        return f'Drop duplicates'
-
-    @classmethod
-    def get_modified_dataframe_indexes( # type: ignore
-        cls, 
-        sheet_index: int,
-        column_ids: List[ColumnID],
-        keep: str,
-        **params
-    ) -> Set[int]:
-        return {sheet_index}
+    def get_modified_dataframe_indexes(cls, params: Dict[str, Any]) -> Set[int]:
+        return {get_param(params, 'sheet_index')}
