@@ -12,8 +12,7 @@ import pandas as pd
 from mitosheet.code_chunks.code_chunk import CodeChunk
 from mitosheet.code_chunks.step_performers.pivot_code_chunk import (
     USE_INPLACE_PIVOT, PivotCodeChunk)
-from mitosheet.column_headers import flatten_column_header
-from mitosheet.errors import make_invalid_pivot_error, make_no_column_error
+from mitosheet.errors import make_invalid_pivot_error, make_invalid_pivot_filter_error, make_no_column_error
 from mitosheet.state import DATAFRAME_SOURCE_PIVOTED, State
 from mitosheet.step_performers.filter import (combine_filters,
                                               get_applied_filter)
@@ -94,6 +93,7 @@ class PivotStepPerformer(StepPerformer):
             params['values_column_ids_map'][column_id] = new_aggregation_function_names
 
         return params
+    
 
     @classmethod
     def execute(cls, prev_state: State, params: Dict[str, Any]) -> Tuple[State, Optional[Dict[str, Any]]]:
@@ -105,6 +105,7 @@ class PivotStepPerformer(StepPerformer):
         flatten_column_headers: bool = get_param(params, 'flatten_column_headers')
         destination_sheet_index: Optional[int] = get_param(params, 'destination_sheet_index')
         use_deprecated_id_algorithm: bool = get_param(params, 'use_deprecated_id_algorithm') if get_param(params, 'use_deprecated_id_algorithm') else False
+        public_interface_version: bool = get_param(params, 'public_interface_version')
         
         # Get just the column headers in a list, for convenience
         pivot_rows = [prev_state.column_ids.get_column_header_by_id(sheet_index, cit['column_id']) for cit in pivot_rows_column_ids_with_transforms]
@@ -132,7 +133,7 @@ class PivotStepPerformer(StepPerformer):
         columns_used = set(pivot_rows).union(set(pivot_columns)).union(set(values.keys()))
         missing_pivot_keys = columns_used.difference(prev_state.dfs[sheet_index].keys())
         if len(missing_pivot_keys) > 0:
-            raise make_no_column_error(missing_pivot_keys)
+            raise make_no_column_error(missing_pivot_keys, error_modal=False)
 
         # Create the post state, it can be a shallow copy
         post_state = prev_state.copy()
@@ -145,7 +146,8 @@ class PivotStepPerformer(StepPerformer):
             pivot_columns_with_transforms,
             values,
             pivot_filters,
-            flatten_column_headers
+            flatten_column_headers,
+            public_interface_version
         )
         pandas_processing_time = perf_counter() - pandas_start_time
         # Create a new df name if we don't have one
@@ -186,6 +188,7 @@ class PivotStepPerformer(StepPerformer):
                 get_param(params, 'values_column_ids_map'),
                 get_param(params, 'flatten_column_headers'),
                 get_param(execution_data if execution_data is not None else {}, 'was_series'),
+                get_param(params, 'public_interface_version'),
             )
         ]
 
@@ -285,7 +288,8 @@ def _execute_pivot(
         pivot_columns_with_transforms: List[ColumnHeaderWithPivotTransform], 
         values: Dict[ColumnHeader, Collection[str]],
         pivot_filters: List[ColumnHeaderWithFilter],
-        flatten_column_headers: bool
+        flatten_column_headers: bool,
+        public_interface_version: int
     ) -> Tuple[pd.DataFrame, bool]:
     """
     Helper function for executing the pivot on a specific dataframe
@@ -303,10 +307,12 @@ def _execute_pivot(
 
     # First, we do the filtering on the initial dataframe, according to the pivot_filters
     if len(pivot_filters) > 0:
-        filters = [
-            get_applied_filter(df, pf['column_header'], pf['filter'])
-            for pf in pivot_filters
-        ]
+        filters = []
+        for pf in pivot_filters:
+            try:
+                filters.append(get_applied_filter(df, pf['column_header'], pf['filter']))
+            except:
+                raise make_invalid_pivot_filter_error(pf['column_header'], pf['filter']['condition'])
         full_filter = combine_filters('And', filters)
         df = df[full_filter] # TODO: do we have to make a copy
 
@@ -367,6 +373,15 @@ def _execute_pivot(
         was_series = True
 
     if flatten_column_headers:
+
+        # Get the correct version of flatten column header
+        if public_interface_version == 1:
+            from mitosheet.public.v1 import flatten_column_header
+        elif public_interface_version == 2:
+            from mitosheet.public.v2 import flatten_column_header
+        else:
+            raise Exception(f'Please add support for public_interface_version={public_interface_version}')
+
         # See comment in pivot_code_chunk, we avoid using inplace=True post pandas 1.5.0, as
         # it is depricated
         if USE_INPLACE_PIVOT:
