@@ -1,17 +1,23 @@
+#!/usr/bin/env python
+# coding: utf-8
+
+# Copyright (c) Saga Inc.
+# Distributed under the terms of the GPL License.
+import subprocess
+import sys
 from typing import Any, Dict
+
 import atheris
 import pandas as pd
-import sys
 
+from mitosheet.mito_backend import get_mito_frontend_code
 
 with atheris.instrument_imports():
-    from mitosheet.tests.test_utils import MitoWidgetTestWrapper
-    from mitosheet.step_performers.filter import FC_NUMBER_EXACTLY
     import mitosheet
-    from mitosheet.tests.test_utils import create_mito_wrapper_dfs
-    from mitosheet.sheet_functions.types import (
-        NUMBER_SERIES,
-    )
+    from mitosheet.step_performers.filter import FC_NUMBER_EXACTLY
+    from mitosheet.tests.test_utils import (MitoWidgetTestWrapper,
+                                            create_mito_wrapper_dfs)
+
 
 
 def get_random_event(fdp: atheris.FuzzedDataProvider) -> Dict[str, Any]:
@@ -94,7 +100,6 @@ def send_random_event(mito: MitoWidgetTestWrapper, fdp: atheris.FuzzedDataProvid
             random_sheet_index,
             random_column_header,
             'And',
-            NUMBER_SERIES,
             FC_NUMBER_EXACTLY,
             1
         )
@@ -174,13 +179,26 @@ NUM_EVENTS = 20
 def TestMito(data):
     import random
     fdp = atheris.FuzzedDataProvider(data)
-    mito = create_mito_wrapper_dfs(pd.DataFrame({'A': [random.randint(0, 100) for _ in range(50)], 'B': [random.randint(0, 100) for _ in range(50)]}))
 
-    for _ in range(NUM_EVENTS):
-        send_random_event(mito, fdp)
+    df = pd.DataFrame({'A': []})
+    mito = create_mito_wrapper_dfs(df)
+    frontend_code = get_mito_frontend_code('1', '2', '3', mito.mito_backend)
+    
+    file = 'tests/out.js'
+    with open(file, 'w+') as f:
+        f.write(frontend_code)
 
-    print("NUM STEPS:", len(mito.steps))
+    p = subprocess.Popen(['node', file], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    (_, err) = p.communicate()
+    p.wait()
+
+    # we want to make sure that there are no failures in parsing, that it runs up to the 
+    # ReferenceError: document is not defined 
+    assert 'SyntaxError' not in err.decode('utf-8') 
+    assert 'ReferenceError' in err.decode('utf-8')
+
+    print("NUM STEPS:", len(mito.steps_including_skipped))
 
 
 atheris.Setup(sys.argv, TestMito)
-atheris.Fuzz()
\ No newline at end of file
+atheris.Fuzz()
