@@ -40,7 +40,10 @@ UJ_MITOSHEET_LAST_UPGRADED_DATE = 'mitosheet_last_upgraded_date'
 UJ_MITOSHEET_LAST_FIFTY_USAGES = 'mitosheet_last_fifty_usages'
 UJ_MITOSHEET_TELEMETRY = 'mitosheet_telemetry'
 UJ_MITOSHEET_PRO = 'mitosheet_pro'
+UJ_MITOSHEET_ENTERPRISE = 'mitosheet_enterprise'
 UJ_EXPERIMENT = 'experiment'
+UJ_RECEIVED_CHECKLISTS = 'received_checklists'
+UJ_AI_PRIVACY_POLICY = 'ai_privacy_policy'
 
 
 # This was the final version of the user.json with user_json_version == 1
@@ -218,7 +221,90 @@ USER_JSON_VERSION_6 = {
     UJ_EXPERIMENT: get_new_experiment()
 }
 
+"""
+Adds UJ_RECEIVED_CHECKLISTS, which is a list of checklists that the user has received,
+and the steps for each checklist they have been through, with the format:
+{"onboarding_checklist": ['signup', 'import', 'filter', 'pivot', 'graph']}
+"""
+USER_JSON_VERSION_7 = {
+    # The new version of the user json object
+    UJ_USER_JSON_VERSION: 7,
+    # The static id of the user
+    UJ_STATIC_USER_ID: get_random_id(),
+    # A random secret that the user can use as salt when hashing things
+    UJ_USER_SALT: get_random_id(),
+    # Email of the user
+    UJ_USER_EMAIL: '',
+    # Tours that the user has received
+    UJ_RECEIVED_TOURS: [],
+    # A list of all the feedback the user has given
+    UJ_FEEDBACKS: [],
+    UJ_FEEDBACKS_V2: {},
+    UJ_MITOSHEET_CURRENT_VERSION: __version__,
+    UJ_MITOSHEET_LAST_UPGRADED_DATE: datetime.today().strftime('%Y-%m-%d'),
+    UJ_MITOSHEET_LAST_FIFTY_USAGES: [datetime.today().strftime('%Y-%m-%d')],
+    UJ_MITOSHEET_TELEMETRY: True,
+    UJ_MITOSHEET_PRO: False,
+    UJ_EXPERIMENT: get_new_experiment(),
+    UJ_RECEIVED_CHECKLISTS: {}
+}
+
+"""
+Adds UJ_MITOSHEET_ENTERPRISE and sets it equal to False
+"""
+USER_JSON_VERSION_8 = {
+    # The new version of the user json object
+    UJ_USER_JSON_VERSION: 8,
+    # The static id of the user
+    UJ_STATIC_USER_ID: get_random_id(),
+    # A random secret that the user can use as salt when hashing things
+    UJ_USER_SALT: get_random_id(),
+    # Email of the user
+    UJ_USER_EMAIL: '',
+    # Tours that the user has received
+    UJ_RECEIVED_TOURS: [],
+    # A list of all the feedback the user has given
+    UJ_FEEDBACKS: [],
+    UJ_FEEDBACKS_V2: {},
+    UJ_MITOSHEET_CURRENT_VERSION: __version__,
+    UJ_MITOSHEET_LAST_UPGRADED_DATE: datetime.today().strftime('%Y-%m-%d'),
+    UJ_MITOSHEET_LAST_FIFTY_USAGES: [datetime.today().strftime('%Y-%m-%d')],
+    UJ_MITOSHEET_TELEMETRY: True,
+    UJ_MITOSHEET_PRO: False,
+    UJ_MITOSHEET_ENTERPRISE: False,
+    UJ_EXPERIMENT: get_new_experiment(),
+    UJ_RECEIVED_CHECKLISTS: {}
+}
+
+"""
+Adds UJ_AI_PRIVACY_POLICY and sets it equal to False
+"""
+USER_JSON_VERSION_9 = {
+    # The new version of the user json object
+    UJ_USER_JSON_VERSION: 9,
+    # The static id of the user
+    UJ_STATIC_USER_ID: get_random_id(),
+    # A random secret that the user can use as salt when hashing things
+    UJ_USER_SALT: get_random_id(),
+    # Email of the user
+    UJ_USER_EMAIL: '',
+    # Tours that the user has received
+    UJ_RECEIVED_TOURS: [],
+    # A list of all the feedback the user has given
+    UJ_FEEDBACKS: [],
+    UJ_FEEDBACKS_V2: {},
+    UJ_MITOSHEET_CURRENT_VERSION: __version__,
+    UJ_MITOSHEET_LAST_UPGRADED_DATE: datetime.today().strftime('%Y-%m-%d'),
+    UJ_MITOSHEET_LAST_FIFTY_USAGES: [datetime.today().strftime('%Y-%m-%d')],
+    UJ_MITOSHEET_TELEMETRY: True,
+    UJ_MITOSHEET_PRO: False,
+    UJ_MITOSHEET_ENTERPRISE: False,
+    UJ_EXPERIMENT: get_new_experiment(),
+    UJ_RECEIVED_CHECKLISTS: {},
+    UJ_AI_PRIVACY_POLICY: False
+}
+
 
 # This is the most up to date user json, and you must update it when
 # you add a new schema
-USER_JSON_DEFAULT = USER_JSON_VERSION_6
\ No newline at end of file
+USER_JSON_DEFAULT = USER_JSON_VERSION_9
\ No newline at end of file
